<?php

namespace Litecms\Packageplan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Packageplan\Models\Packageplan;

class PackageplanPolicy
{

    /**
     * Determine if the given user can view the packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function view(UserPolicy $user, Packageplan $packageplan)
    {
        if ($user->canDo('packageplan.packageplan.view') && $user->isAdmin()) {
            return true;
        }

        return $packageplan->user_id == user_id() && $packageplan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('packageplan.packageplan.create');
    }

    /**
     * Determine if the given user can update the given packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function update(UserPolicy $user, Packageplan $packageplan)
    {
        if ($user->canDo('packageplan.packageplan.edit') && $user->isAdmin()) {
            return true;
        }

        return $packageplan->user_id == user_id() && $packageplan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Packageplan $packageplan)
    {
        return $packageplan->user_id == user_id() && $packageplan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Packageplan $packageplan)
    {
        if ($user->canDo('packageplan.packageplan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given packageplan.
     *
     * @param UserPolicy $user
     * @param Packageplan $packageplan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Packageplan $packageplan)
    {
        if ($user->canDo('packageplan.packageplan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
